# skelly_tracker

Currently, the bare bones of a tracking backend for freemocap.

## Run skelly_tracker

Currently, it is not pip installable. Download it by running `git clone https://github.com/freemocap/skelly_tracker`. 

Change directories to skelly_tracker with `cd skelly_tracker`, and install the requirements with `pip install .`.

Then it can be run with `skelly_tracker`.

## Using skelly_tracker

A GUI should pop up that looks like this: 

<img width="591" alt="Image of skelly_tracker GUI" src="https://github.com/freemocap/skelly_tracker/assets/24758117/8767a7fb-2535-407c-99fb-40295ee5af93">


Choose your image in the file dialog and click run to see the image annotated with the tracking information.
